@@ -7,7 +7,13 @@ use Module::Install::Base; @ISA = qw(Module::Install::Base);
 
 sub WriteAll {
     my $self = shift;
-    my %args = (check_nmake => 1, meta => 1, sign => 0, @_);
+    my %args = (
+        meta => 1,
+        sign => 0,
+        inline => 0,
+        check_nmake => 1,
+        @_
+    );
 
     $self->sign(1) if $args{sign};
     $self->Meta->write if $args{meta};
@@ -20,7 +26,13 @@ sub WriteAll {
 	$self->check_nmake if $args{check_nmake};
         $self->makemaker_args( PL_FILES => {} )
             unless $self->makemaker_args->{'PL_FILES'};
-	$self->Makefile->write;
+
+        if ($args{inline}) {
+            $self->Inline->write;
+        }
+        else {
+            $self->Makefile->write;
+        }
     }
 }
 
